@@ -24,19 +24,18 @@ Functional tests for `shade` endpoint resource.
 import string
 import random
 
-from shade import operator_cloud
 from shade.exc import OpenStackCloudException
-from shade.tests import base
+from shade.exc import OpenStackCloudUnavailableFeature
+from shade.tests.functional import base
 
 
-class TestEndpoints(base.TestCase):
+class TestEndpoints(base.BaseFunctionalTestCase):
 
     endpoint_attributes = ['id', 'region', 'publicurl', 'internalurl',
                            'service_id', 'adminurl']
 
     def setUp(self):
         super(TestEndpoints, self).setUp()
-        self.operator_cloud = operator_cloud(cloud='devstack-admin')
 
         # Generate a random name for services and regions in this test
         self.new_item_name = 'test_' + ''.join(
@@ -81,34 +80,69 @@ class TestEndpoints(base.TestCase):
         service_name = self.new_item_name + '_create'
 
         service = self.operator_cloud.create_service(
-            name=service_name, service_type='test_type',
+            name=service_name, type='test_type',
             description='this is a test description')
 
-        endpoint = self.operator_cloud.create_endpoint(
+        endpoints = self.operator_cloud.create_endpoint(
             service_name_or_id=service['id'],
             public_url='http://public.test/',
             internal_url='http://internal.test/',
             admin_url='http://admin.url/',
             region=service_name)
 
-        self.assertIsNotNone(endpoint.get('id'))
+        self.assertNotEqual([], endpoints)
+        self.assertIsNotNone(endpoints[0].get('id'))
 
         # Test None parameters
-        endpoint = self.operator_cloud.create_endpoint(
+        endpoints = self.operator_cloud.create_endpoint(
             service_name_or_id=service['id'],
             public_url='http://public.test/',
             region=service_name)
 
-        self.assertIsNotNone(endpoint.get('id'))
+        self.assertNotEqual([], endpoints)
+        self.assertIsNotNone(endpoints[0].get('id'))
+
+    def test_update_endpoint(self):
+        if self.operator_cloud.cloud_config.get_api_version(
+            'identity').startswith('2'):
+            # NOTE(SamYaple): Update endpoint only works with v3 api
+            self.assertRaises(OpenStackCloudUnavailableFeature,
+                              self.operator_cloud.update_endpoint,
+                              'endpoint_id1')
+        else:
+            service = self.operator_cloud.create_service(
+                name='service1', type='test_type')
+            endpoint = self.operator_cloud.create_endpoint(
+                service_name_or_id=service['id'],
+                url='http://admin.url/',
+                interface='admin',
+                region='orig_region',
+                enabled=False)[0]
+
+            new_service = self.operator_cloud.create_service(
+                name='service2', type='test_type')
+            new_endpoint = self.operator_cloud.update_endpoint(
+                endpoint.id,
+                service_name_or_id=new_service.id,
+                url='http://public.url/',
+                interface='public',
+                region='update_region',
+                enabled=True)
+
+            self.assertEqual(new_endpoint.url, 'http://public.url/')
+            self.assertEqual(new_endpoint.interface, 'public')
+            self.assertEqual(new_endpoint.region, 'update_region')
+            self.assertEqual(new_endpoint.service_id, new_service.id)
+            self.assertTrue(new_endpoint.enabled)
 
     def test_list_endpoints(self):
         service_name = self.new_item_name + '_list'
 
         service = self.operator_cloud.create_service(
-            name=service_name, service_type='test_type',
+            name=service_name, type='test_type',
             description='this is a test description')
 
-        endpoint = self.operator_cloud.create_endpoint(
+        endpoints = self.operator_cloud.create_endpoint(
             service_name_or_id=service['id'],
             public_url='http://public.test/',
             internal_url='http://internal.test/',
@@ -118,12 +152,21 @@ class TestEndpoints(base.TestCase):
         found = False
         for e in observed_endpoints:
             # Test all attributes are returned
-            if e['id'] == endpoint['id']:
-                found = True
-                self.assertEqual(service['id'], e['service_id'])
-                self.assertEqual('http://public.test/', e['publicurl'])
-                self.assertEqual('http://internal.test/', e['internalurl'])
-                self.assertEqual(service_name, e['region'])
+            for endpoint in endpoints:
+                if e['id'] == endpoint['id']:
+                    found = True
+                    self.assertEqual(service['id'], e['service_id'])
+                    if 'interface' in e:
+                        if 'interface' == 'internal':
+                            self.assertEqual('http://internal.test/', e['url'])
+                        elif 'interface' == 'public':
+                            self.assertEqual('http://public.test/', e['url'])
+                    else:
+                        self.assertEqual('http://public.test/',
+                                         e['publicurl'])
+                        self.assertEqual('http://internal.test/',
+                                         e['internalurl'])
+                    self.assertEqual(service_name, e['region'])
 
         self.assertTrue(found, msg='new endpoint not found in endpoints list!')
 
@@ -131,22 +174,25 @@ class TestEndpoints(base.TestCase):
         service_name = self.new_item_name + '_delete'
 
         service = self.operator_cloud.create_service(
-            name=service_name, service_type='test_type',
+            name=service_name, type='test_type',
             description='this is a test description')
 
-        endpoint = self.operator_cloud.create_endpoint(
+        endpoints = self.operator_cloud.create_endpoint(
             service_name_or_id=service['id'],
             public_url='http://public.test/',
             internal_url='http://internal.test/',
             region=service_name)
 
-        self.operator_cloud.delete_endpoint(endpoint['id'])
+        self.assertNotEqual([], endpoints)
+        for endpoint in endpoints:
+            self.operator_cloud.delete_endpoint(endpoint['id'])
 
         observed_endpoints = self.operator_cloud.list_endpoints()
         found = False
         for e in observed_endpoints:
-            if e['id'] == endpoint['id']:
-                found = True
-                break
+            for endpoint in endpoints:
+                if e['id'] == endpoint['id']:
+                    found = True
+                    break
         self.failUnlessEqual(
             False, found, message='new endpoint was not deleted!')
