@@ -43,7 +43,7 @@ class TestCreateServer(base.TestCase):
         Test that an exception in the novaclient create raises an exception in
         create_server.
         """
-        with patch("shade.OpenStackCloud"):
+        with patch("shade.OpenStackCloud.nova_client"):
             config = {
                 "servers.create.side_effect": Exception("exception"),
             }
@@ -57,7 +57,7 @@ class TestCreateServer(base.TestCase):
         Test that an exception when attempting to get the server instance via
         the novaclient raises an exception in create_server.
         """
-        with patch("shade.OpenStackCloud"):
+        with patch("shade.OpenStackCloud.nova_client"):
             config = {
                 "servers.create.return_value": Mock(status="BUILD"),
                 "servers.get.side_effect": Exception("exception")
@@ -74,7 +74,7 @@ class TestCreateServer(base.TestCase):
         """
         build_server = fakes.FakeServer('1234', '', 'BUILD')
         error_server = fakes.FakeServer('1234', '', 'ERROR')
-        with patch("shade.OpenStackCloud"):
+        with patch("shade.OpenStackCloud.nova_client"):
             config = {
                 "servers.create.return_value": build_server,
                 "servers.get.return_value": error_server,
@@ -89,14 +89,18 @@ class TestCreateServer(base.TestCase):
         Test that a server error while waiting for the server to spawn
         raises an exception in create_server.
         """
-        with patch("shade.OpenStackCloud"):
+        with patch("shade.OpenStackCloud.nova_client"):
             build_server = fakes.FakeServer('1234', '', 'BUILD')
             error_server = fakes.FakeServer('1234', '', 'ERROR')
+            fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
+                                                    '1.1.1.1', '2.2.2.2',
+                                                    '5678')
             config = {
                 "servers.create.return_value": build_server,
                 "servers.get.return_value": build_server,
                 "servers.list.side_effect": [
-                    [build_server], [error_server]]
+                    [build_server], [error_server]],
+                "floating_ips.list.return_value": [fake_floating_ip]
             }
             OpenStackCloud.nova_client = Mock(**config)
             self.assertRaises(
@@ -109,7 +113,7 @@ class TestCreateServer(base.TestCase):
         Test that a timeout while waiting for the server to spawn raises an
         exception in create_server.
         """
-        with patch("shade.OpenStackCloud"):
+        with patch("shade.OpenStackCloud.nova_client"):
             fake_server = fakes.FakeServer('1234', '', 'BUILD')
             config = {
                 "servers.create.return_value": fake_server,
@@ -127,11 +131,15 @@ class TestCreateServer(base.TestCase):
         Test that create_server with no wait and no exception in the
         novaclient create call returns the server instance.
         """
-        with patch("shade.OpenStackCloud"):
+        with patch("shade.OpenStackCloud.nova_client"):
             fake_server = fakes.FakeServer('1234', '', 'BUILD')
+            fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
+                                                    '1.1.1.1', '2.2.2.2',
+                                                    '5678')
             config = {
                 "servers.create.return_value": fake_server,
-                "servers.get.return_value": fake_server
+                "servers.get.return_value": fake_server,
+                "floating_ips.list.return_value": [fake_floating_ip]
             }
             OpenStackCloud.nova_client = Mock(**config)
             self.assertEqual(
@@ -147,13 +155,17 @@ class TestCreateServer(base.TestCase):
         """
         Test that a server with an admin_pass passed returns the password
         """
-        with patch("shade.OpenStackCloud"):
+        with patch("shade.OpenStackCloud.nova_client"):
             fake_server = fakes.FakeServer('1234', '', 'BUILD')
             fake_create_server = fakes.FakeServer('1234', '', 'BUILD',
                                                   adminPass='ooBootheiX0edoh')
+            fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
+                                                    '1.1.1.1', '2.2.2.2',
+                                                    '5678')
             config = {
                 "servers.create.return_value": fake_create_server,
-                "servers.get.return_value": fake_server
+                "servers.get.return_value": fake_server,
+                "floating_ips.list.return_value": [fake_floating_ip]
             }
             OpenStackCloud.nova_client = Mock(**config)
             self.assertEqual(
@@ -253,15 +265,19 @@ class TestCreateServer(base.TestCase):
         Test that create_server with a wait throws an exception if the
         server doesn't have addresses.
         """
-        with patch("shade.OpenStackCloud"):
+        with patch("shade.OpenStackCloud.nova_client"):
             build_server = fakes.FakeServer('1234', '', 'BUILD')
             fake_server = fakes.FakeServer('1234', '', 'ACTIVE')
+            fake_floating_ip = fakes.FakeFloatingIP('1234', 'ippool',
+                                                    '1.1.1.1', '2.2.2.2',
+                                                    '5678')
             config = {
                 "servers.create.return_value": build_server,
                 "servers.get.return_value": [build_server, None],
                 "servers.list.side_effect": [
                     [build_server], [fake_server]],
                 "servers.delete.return_value": None,
+                "floating_ips.list.return_value": [fake_floating_ip]
             }
             OpenStackCloud.nova_client = Mock(**config)
             self.client._SERVER_AGE = 0
