@@ -47,6 +47,7 @@ class TestFloatingIP(base.TestCase):
         floating_ip_dict = {
             "id": "this-is-a-floating-ip-id",
             "fixed_ip_address": None,
+            "internal_network": None,
             "floating_ip_address": "203.0.113.29",
             "network": "this-is-a-net-or-pool-id",
             "attached": False,
@@ -75,7 +76,9 @@ class TestFloatingIP(base.TestCase):
 
         self.client.add_ips_to_server(server_dict, ip_pool=pool)
 
-        mock_add_ip_from_pool.assert_called_with(server_dict, pool, reuse=True)
+        mock_add_ip_from_pool.assert_called_with(
+            server_dict, pool, reuse=True, wait=False, timeout=60,
+            fixed_address=None, nat_destination=None)
 
     @patch.object(OpenStackCloud, 'nova_client')
     @patch.object(OpenStackCloud, 'add_ip_list')
@@ -90,10 +93,11 @@ class TestFloatingIP(base.TestCase):
 
         self.client.add_ips_to_server(server_dict, ips=ips)
 
-        mock_add_ip_list.assert_called_with(server_dict, ips)
+        mock_add_ip_list.assert_called_with(
+            server_dict, ips, wait=False, timeout=60, fixed_address=None)
 
     @patch.object(OpenStackCloud, 'nova_client')
-    @patch.object(OpenStackCloud, 'add_auto_ip')
+    @patch.object(OpenStackCloud, '_add_auto_ip')
     def test_add_ips_to_server_auto_ip(
             self, mock_add_auto_ip, mock_nova_client):
         server = FakeServer(
